@@ -37,22 +37,10 @@
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <gdk/gdk.h>
-#include <gdk/gdkkeysyms.h>
 #include <gdk/gdkprivate.h>
 #include <gdk/gdkx.h>
-#include <gtk/gtkalignment.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkrc.h>
-#include <gtk/gtkselection.h>
-#include <gtk/gtkseparatormenuitem.h>
-#include <gtk/gtksignal.h>
-#include <pango/pangoft2.h>
+#include <gtk/gtk.h>
 #include <math.h>
-
 #include "eel-marshal.h"
 #include "eel-marshal.c"
 
@@ -68,107 +56,6 @@
 #define MINIMUM_ON_SCREEN_HEIGHT	100
 
 
-/**
- * eel_gtk_button_new_with_stock_icon:
- * 
- * @label: the button label, which may include a mnemonic accelerator.
- * @stock_id: the stock icon to use.
- *
- * Creates a GtkButton with a mnemonic label and a stock icon.
- *
- * Return value: a new GtkButton widget.
- **/
-GtkWidget*
-eel_gtk_button_new_with_stock_icon (const gchar *label, const gchar *stock_id)
-{
-	GtkWidget *button, *l, *image, *hbox, *align;
-
-	/* This is mainly copied from gtk_button_construct_child(). */
-	button = gtk_button_new ();
-	l = gtk_label_new_with_mnemonic (label);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (l), GTK_WIDGET (button));
-	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
-	hbox = gtk_hbox_new (FALSE, 2);
-	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-	gtk_box_pack_end (GTK_BOX (hbox), l, FALSE, FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (button), align);
-	gtk_container_add (GTK_CONTAINER (align), hbox);
-	gtk_widget_show_all (align);
-
-	return button;
-}
-
-/**
- * eel_gtk_button_set_padding
- * 
- * Adds some padding around the contained widget in the button (typically the label).
- * @button: a GtkButton
- * @pad_amount: number of pixels of space to add around the button's contents.
- * GNOME_PAD_SMALL is a typical value.
- **/
-void
-eel_gtk_button_set_padding (GtkButton *button, int pad_amount)
-{
-	GtkWidget *child;
-
-	g_return_if_fail (GTK_IS_BUTTON (button));
-	g_return_if_fail (pad_amount > 0);
-
-	child = GTK_BIN (button)->child;
-
-	if (GTK_IS_MISC (child)) {
-		gtk_misc_set_padding
-			(GTK_MISC (child), pad_amount, pad_amount);
-	}
-}
-
-/**
- * eel_gtk_signal_connect_free_data_custom:
- * 
- * Attach a function pointer and user data to a signal, and call a
- * a destroy function on the user data when the signal is disconnected.
- * @object: the object which emits the signal. For example, a button in the button press signal.
- * @name: the name of the signal.
- * @func: function pointer to attach to the signal.
- * @data: the user data associated with the function.
- * @destroy_func: the function to call on the user data when the signal
- * is disconnected.
- **/
-guint
-eel_gtk_signal_connect_free_data_custom (GtkObject       *object,
-					 const gchar     *name,
-					 GtkSignalFunc    func,
-					 gpointer         data,
-					 GtkDestroyNotify destroy_func)
-{
-	return g_signal_connect_closure (
-		object, name,
-		g_cclosure_new (func, data, (GClosureNotify) destroy_func),
-		FALSE);
-}
-
-/**
- * eel_gtk_signal_connect_free_data:
- * 
- * Attach a function pointer and user data to a signal, and free
- * the user data when the signal is disconnected.
- * @object: the object which emits the signal. For example, a button in the button press signal.
- * @name: the name of the signal.
- * @func: function pointer to attach to the signal.
- * @data: the user data associated with the function. g_free() will be called on
- * this user data when the signal is disconnected.
- **/
-guint
-eel_gtk_signal_connect_free_data (GtkObject *object,
-				       const gchar *name,
-				       GtkSignalFunc func,
-				       gpointer data)
-{
-	return eel_gtk_signal_connect_free_data_custom
-		(object, name, func, data, g_free);
-}
-
 /**
  * eel_gtk_window_get_geometry_string:
  * @window: a #GtkWindow
@@ -318,7 +205,7 @@ sanity_check_window_position (int *left, int *top)
 }
 
 static void
-sanity_check_window_dimensions (int *width, int *height)
+sanity_check_window_dimensions (guint *width, guint *height)
 {
 	g_assert (width != NULL);
 	g_assert (height != NULL);
@@ -361,8 +248,6 @@ eel_gtk_window_set_initial_geometry (GtkWindow *window,
 	int screen_width, screen_height;
 
 	g_return_if_fail (GTK_IS_WINDOW (window));
-	g_return_if_fail (!(geometry_flags & EEL_GDK_WIDTH_VALUE) || width > 0);
-	g_return_if_fail (!(geometry_flags & EEL_GDK_HEIGHT_VALUE) || height > 0);
 
 	/* Setting the default size doesn't work when the window is already showing.
 	 * Someday we could make this move an already-showing window, but we don't
@@ -397,7 +282,7 @@ eel_gtk_window_set_initial_geometry (GtkWindow *window,
 
 	if ((geometry_flags & EEL_GDK_WIDTH_VALUE) && (geometry_flags & EEL_GDK_HEIGHT_VALUE)) {
 		sanity_check_window_dimensions (&width, &height);
-		gtk_window_set_default_size (GTK_WINDOW (window), width, height);
+		gtk_window_set_default_size (GTK_WINDOW (window), (int)width, (int)height);
 	}
 }
 
@@ -458,19 +343,6 @@ eel_gtk_window_set_initial_geometry_from_string (GtkWindow *window,
 	eel_gtk_window_set_initial_geometry (window, geometry_flags, left, top, width, height);
 }
 
-/**
- * eel_truncate_text_for_menu_item:
- * 
- * Given an arbitrary string, returns a newly-allocated string
- * suitable for use as a menu item label. Truncates long strings 
- * in the middle.
- */
-char *
-eel_truncate_text_for_menu_item (const char *text)
-{
-	return eel_str_middle_truncate (text, MAXIMUM_MENU_TITLE_LENGTH);
-}
-
 /**
  * eel_pop_up_context_menu:
  * 
@@ -564,6 +436,26 @@ eel_gtk_menu_set_item_visibility (GtkMenu *menu, int index, gboolean visible)
 	g_list_free (children);
 }
 
+GtkWidget *
+eel_gtk_menu_tool_button_get_button (GtkMenuToolButton *tool_button)
+{
+	GtkContainer *container;
+	GList *children;
+	GtkWidget *button;
+
+	g_return_val_if_fail (GTK_IS_MENU_TOOL_BUTTON (tool_button), NULL);
+
+	/* The menu tool button's button is the first child
+	 * of the child hbox. */
+	container = GTK_CONTAINER (gtk_bin_get_child (GTK_BIN (tool_button)));
+	children = gtk_container_get_children (container);
+	button = GTK_WIDGET (children->data);
+
+	g_list_free (children);
+
+	return button;
+}
+
 gboolean
 eel_point_in_allocation (const GtkAllocation *allocation,
 			      int x, int y)
@@ -611,32 +503,6 @@ eel_gtk_widget_set_shown (GtkWidget *widget, gboolean shown)
 	}
 }
 
-/**
- * eel_gtk_widget_set_font_by_name
- *
- * Sets the font for a widget, managing the font and style objects.
- * @widget: The widget
- **/
-void
-eel_gtk_widget_set_font_by_name (GtkWidget *widget, const char *font_name)
-{
-	PangoFontDescription *font_desc;
-	
-	g_return_if_fail (GTK_IS_WIDGET (widget));
-	g_return_if_fail (font_name != NULL);
-
-	font_desc = pango_font_description_from_string (font_name);
-
-	if (font_desc == NULL) {
-		g_warning ("Bad font name '%s'", font_name);
-		return;
-	}
-
-	gtk_widget_modify_font (widget, font_desc);
-
-	pango_font_description_free (font_desc);
-}
-
 /* This stuff is stolen from Gtk. */
 
 typedef struct DisconnectInfo {
@@ -728,13 +594,13 @@ static void
 while_realized_disconnecter (GtkObject *object,
 			     RealizeDisconnectInfo *info)
 {
-	g_return_if_fail (GTK_IS_OBJECT (object));
-	g_return_if_fail (info != NULL);
-	g_return_if_fail (GTK_IS_OBJECT (info->object));
-	g_return_if_fail (info->object_destroy_handler != 0);
-	g_return_if_fail (info->object_destroy_handler != 0);
-	g_return_if_fail (info->realized_widget_destroy_handler != 0);
-	g_return_if_fail (info->realized_widget_unrealized_handler != 0);
+	g_assert (GTK_IS_OBJECT (object));
+	g_assert (info != NULL);
+	g_assert (GTK_IS_OBJECT (info->object));
+	g_assert (info->object_destroy_handler != 0);
+	g_assert (info->object_destroy_handler != 0);
+	g_assert (info->realized_widget_destroy_handler != 0);
+	g_assert (info->realized_widget_unrealized_handler != 0);
 
  	g_signal_handler_disconnect (info->object, info->object_destroy_handler);
  	g_signal_handler_disconnect (info->object, info->signal_handler);
@@ -1151,40 +1017,6 @@ eel_gtk_get_system_font (void)
 	return font;
 }
 
-static PangoContext *
-create_pango_ft2_context (PangoContext *base_context)
-{
-	PangoContext *context;
-			
-	context = eel_pango_ft2_get_context ();
-
-	pango_context_set_language (context, pango_context_get_language (base_context));
-	pango_context_set_base_dir (context, pango_context_get_base_dir (base_context));
-	pango_context_set_font_description (context, pango_context_get_font_description (base_context));
-
-	return context;
-}
-
-PangoContext *
-eel_gtk_widget_get_pango_ft2_context (GtkWidget *widget)
-{
-	static GQuark quark_widget_pango_ft2_context;
-	PangoContext *context;
-
-	if (quark_widget_pango_ft2_context == 0) {
-		quark_widget_pango_ft2_context = g_quark_from_static_string ("eel-ft2-context");
-	}
-  
-	context = g_object_get_qdata (G_OBJECT (widget), quark_widget_pango_ft2_context);
-	if (context == NULL) {
-		context = create_pango_ft2_context (gtk_widget_get_pango_context (widget));
-		g_object_set_qdata_full (G_OBJECT (widget), quark_widget_pango_ft2_context,
-					 context, g_object_unref);
-	}
-	
-	return context;
-}
-
 void
 eel_gtk_widget_get_button_event_location (GtkWidget *widget,
 					  const GdkEventButton *event,
@@ -1265,7 +1097,7 @@ eel_gtk_tree_view_set_activate_on_single_click (GtkTreeView *tree_view,
 		g_signal_handler_disconnect (tree_view, button_press_id);
 		g_object_set_data (G_OBJECT (tree_view), 
 				   "eel-tree-view-activate", 
-				   0);
+				   NULL);
 	} else if (!button_press_id && should_activate) {
 		button_press_id = g_signal_connect 
 			(tree_view,
